@@ -2,6 +2,7 @@ from .__version__ import __version__
 from .base import FAAPI
 from .comment import Comment
 from .journal import Journal
+from .journal import JournalPartial
 from .submission import Submission
 from .submission import SubmissionPartial
 from .user import User
@@ -12,6 +13,7 @@ __all__ = [
     "FAAPI",
     "Comment",
     "Journal",
+    "JournalPartial",
     "Submission",
     "SubmissionPartial",
     "User",
