@@ -40,6 +40,34 @@ class SubmissionBase:
             return other == self.id
         return False
 
+    def __gt__(self, other) -> bool:
+        if isinstance(other, SubmissionBase):
+            return self.id > other.id
+        elif isinstance(other, int):
+            return self.id > other
+        return False
+
+    def __ge__(self, other) -> bool:
+        if isinstance(other, SubmissionBase):
+            return self.id >= other.id
+        elif isinstance(other, int):
+            return self.id >= other
+        return False
+
+    def __lt__(self, other) -> bool:
+        if isinstance(other, SubmissionBase):
+            return self.id < other.id
+        elif isinstance(other, int):
+            return self.id < other
+        return False
+
+    def __le__(self, other) -> bool:
+        if isinstance(other, SubmissionBase):
+            return self.id <= other.id
+        elif isinstance(other, int):
+            return self.id <= other
+        return False
+
     def __iter__(self):
         yield "id", self.id
         yield "title", self.title
